import { ImageSource, Utils } from '@nativescript/core';
import { FloatingActionButtonBase, iconProperty, textProperty } from './fab-common';
export class Fab extends FloatingActionButtonBase {
    constructor() {
        super();
        const btn = MNFloatingActionButton.alloc().init();
        btn.animationScale = 0.95;
        this.nativeView = btn;
    }
    setImage(iconDrawable) {
        const newImageView = UIImageView.alloc().initWithImage(iconDrawable.ios);
        if (newImageView !== null) {
            const button = this.nativeView.subviews[0];
            const oldBadImageView = button.subviews[0];
            oldBadImageView.removeFromSuperview();
            button.addSubview(newImageView);
        }
    }
    [iconProperty.setNative](value) {
        let iconDrawable = null;
        if (Utils.isFileOrResourcePath(value)) {
            iconDrawable = ImageSource.fromFileOrResourceSync(value);
        }
        else {
            iconDrawable = ImageSource.fromBase64Sync('iVBORw0KGgoAAAANSUhEUgAAAJAAAACQAQAAAADPPd8VAAAAAnRSTlMAAHaTzTgAAAAqSURBVHgBY6AMjIJRYP9n0AuNCo0KMf+HgwPDTmgoRMeo0KgQRWAUjAIABsnZRR7bYyUAAAAASUVORK5CYII=');
        }
        this.setImage(iconDrawable);
    }
    [textProperty.setNative](value) {
        const image = this.getImageFromText(value);
        this.setImage(image);
    }
    onLayout(left, top, right, bottom) {
        super.onLayout(left, top, right, bottom);
        this._centerIcon();
    }
    _centerIcon() {
        const frame = this.nativeView.frame;
        const width = frame.size.width;
        const height = frame.size.height;
        const button = this.nativeView.subviews[0];
        const imageView = button.subviews[0];
        imageView.contentMode = 1;
        imageView.frame = CGRectMake(0, 0, width / 2, height / 2);
        imageView.center = CGPointMake(width / 2, height / 2);
    }
}
//# sourceMappingURL=fab.ios.js.map